tests Package
=============

:mod:`tests` Package
--------------------

.. automodule:: CMFDefault.browser.content.tests
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_btreefolder` Module
------------------------------

.. automodule:: CMFDefault.browser.content.tests.test_btreefolder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_document` Module
---------------------------

.. automodule:: CMFDefault.browser.content.tests.test_document
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_favorite` Module
---------------------------

.. automodule:: CMFDefault.browser.content.tests.test_favorite
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_file` Module
-----------------------

.. automodule:: CMFDefault.browser.content.tests.test_file
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_folder` Module
-------------------------

.. automodule:: CMFDefault.browser.content.tests.test_folder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_image` Module
------------------------

.. automodule:: CMFDefault.browser.content.tests.test_image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_link` Module
-----------------------

.. automodule:: CMFDefault.browser.content.tests.test_link
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_metadata` Module
---------------------------

.. automodule:: CMFDefault.browser.content.tests.test_metadata
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: CMFDefault.browser.content.tests.utils
    :members:
    :undoc-members:
    :show-inheritance:

